Designed to combine the matrix of correlation values with the matrix of p-values so that in the cases when the null hypothesis cannot be rejected with a level of confidence indicated by the significance, the correlation is set to zero. Thanks to the package foreach, computation can be done in parallel using the desired number of cores.
combine(m1, m2, sl = 0.05, parallel = FALSE, n_cor = 1,
estimator = "values", d1, d2, p11 = 0, p01 = 0, p10 = 0)matrices whose columns are to be correlated. If no estimation calculations are needed, default is NA.
level of significance for testing the null hypothesis. Default is 0.05.
should the computations for associating the matrices be done in parallel? Default is FALSE
number of cores to be used if the computation is run in parallel. Default is 1
string indicating how the parameters \(p_{11}\), \(p_{01}\), \(p_{10}\), \(p_{00}\) are to be estimated. The default is 'values', which indicates that they are estimated based on the entries of x and y. If estimates=='mean', each \(p_{ij}\) is estimated as the mean of all pairs of column vectors in \(m_1\), and of \(m_2\) if needed. If estimates=='own', the \(p_{ij}\)'s must be given as arguments.
sets of vectors used to estimate \(p_{ij}\) parameters. If just one set is needed set \(d_1\)=\(d_2\).
probability that a bivariate observation is of the type (m,n), where m,n>0.
probability that a bivariate observation is of the type (0,n), where n>0.
probability that a bivariate observation is of the type (n,0), where n>0.
matrix of combined association values and p-values.
To test pairwise monotonic associations of vectors within one set \(m\), run combine(\(m\),\(m\)). Note that the values on the diagonal will not be necessarily significant if the vectors contain 0's, as it can be seen by the formula \(p_{11}^2 t_{11} + 2 * (p_{00} p_{11} - p_{01} p_{10})\). The formula for the variance of the estimator proposed by Pimentel(2009) does not apply in case \(p_{11}\), \(p_{01}\),\(p_{10}\), \(p_{00}\) attain the values 0 or 1. In these cases the R function cor.test is used. Note that while independence implies that the estimator is 0, if the estimator is 0, it does not imply that the vectors are independent.